==> packageinstaller-pkglist_0.3.29.tar.xz: packageinstaller-pkglist/Afrikaan_LO_main.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Afrikaan_LO_main
</name>

<description>
   <am>Afrikaans Language Meta-Package for LibreOffice</am>
   <ar>Afrikaans Language Meta-Package for LibreOffice</ar>
   <be>Afrikaans Language Meta-Package for LibreOffice</be>
   <bg>Afrikaans Language Meta-Package for LibreOffice</bg>
   <bn>Afrikaans Language Meta-Package for LibreOffice</bn>
   <ca>Metapaquet d'idioma Afrikaans per LibreOffice</ca>
   <cs>Afrikaans Language Meta-Package for LibreOffice</cs>
   <da>Afrikaans Language Meta-Package for LibreOffice</da>
   <de>Afrikaans Meta-Paket für LibreOffice</de>
   <el>LibreOffice στα Αφρικανικά</el>
   <en>Afrikaans Language Meta-Package for LibreOffice</en>
   <es_ES>Meta-Paquete de idioma africano para LibreOffice</es_ES>
   <es>Metapaquete de idioma Africano para LibreOffice</es>
   <et>Afrikaans Language Meta-Package for LibreOffice</et>
   <eu>Afrikaans Language Meta-Package for LibreOffice</eu>
   <fa>Afrikaans Language Meta-Package for LibreOffice</fa>
   <fil_PH>Afrikaans Language Meta-Package for LibreOffice</fil_PH>
   <fi>Afrikaaninen kielipaketti LibreOffice:lle</fi>
   <fr_BE>Afrikaans Language Meta-Package for LibreOffice</fr_BE>
   <fr>Méta-Paquet de langue afrikanns pour LibreOffice</fr>
   <gl_ES>Africánder meta-paquete de idioma para LiberOffice</gl_ES>
   <he_IL>חבילת על לשפת אפריקאנס עבור LibreOffice</he_IL>
   <hi>Afrikaans Language Meta-Package for LibreOffice</hi>
   <hr>Afrikaans Language Meta-Package for LibreOffice</hr>
   <hu>Afrikaans Language Meta-Package for LibreOffice</hu>
   <id>Afrikaans Language Meta-Package for LibreOffice</id>
   <is>Afrikaans Language Meta-Package for LibreOffice</is>
   <it>Meta-pacchetto della lingua afrikaans per LibreOffice</it>
   <ja>LibreOffice 用のアフリカーンス語のメタパッケージ</ja>
   <kk>Afrikaans Language Meta-Package for LibreOffice</kk>
   <ko>Afrikaans Language Meta-Package for LibreOffice</ko>
   <lt>Afrikaans Language Meta-Package for LibreOffice</lt>
   <mk>Afrikaans Language Meta-Package for LibreOffice</mk>
   <mr>Afrikaans Language Meta-Package for LibreOffice</mr>
   <nb_NO>Afrikaans Language Meta-Package for LibreOffice</nb_NO>
   <nb>Afrikaans språkpakke for LibreOffice</nb>
   <nl_BE>Afrikaans Language Meta-Package for LibreOffice</nl_BE>
   <nl>Afrikaans Taal Meta-Pakket voor LibreOffice</nl>
   <pl>Meta-pakiet języka Afrikaans dla LibreOffice</pl>
   <pt_BR>Africâner Pacote de Idioma para o LibreOffice</pt_BR>
   <pt>Africander Meta-Pacote de Idioma para LibreOffice</pt>
   <ro>Afrikaans Language Meta-Package for LibreOffice</ro>
   <ru>Afrikaans Language Meta-Package for LibreOffice</ru>
   <sk>Afrikaans Language Meta-Package for LibreOffice</sk>
   <sl>Afrikaan jezikovni meta-paket za LibreOffice</sl>
   <sq>Afrikaans Language Meta-Package for LibreOffice</sq>
   <sr>Afrikaans Language Meta-Package for LibreOffice</sr>
   <sv>Afrikaans Språk Meta-Paket för LibreOffice</sv>
   <th>Meta-Package ภาษา Afrikaans สำหรับ LibreOffice</th>
   <tr>LibreOffice için Afrikaan Dili Üst-Paketi</tr>
   <uk>Afrikaans Language Meta-Package for LibreOffice</uk>
   <vi>Afrikaans Language Meta-Package for LibreOffice</vi>
   <zh_CN>LibreOffice 南非语语言包</zh_CN>
   <zh_HK>Afrikaans Language Meta-Package for LibreOffice</zh_HK>
   <zh_TW>Afrikaans Language Meta-Package for LibreOffice</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-l10n-af
libreoffice-gtk3
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-l10n-af
libreoffice-gtk3
</uninstall_package_names>

</app>

==> packageinstaller-pkglist_0.3.32.tar.xz: packageinstaller-pkglist/Afrikaan_LO_main.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Afrikaan_LO_main
</name>

<description>
   <am>Afrikaans Language Meta-Package for LibreOffice</am>
   <ar>Afrikaans Language Meta-Package for LibreOffice</ar>
   <be>Afrikaans Language Meta-Package for LibreOffice</be>
   <bg>Afrikaans Language Meta-Package for LibreOffice</bg>
   <bn>Afrikaans Language Meta-Package for LibreOffice</bn>
   <ca>Metapaquet d'idioma Afrikaans per LibreOffice</ca>
   <cs>Afrikaans Language Meta-Package for LibreOffice</cs>
   <da>Afrikaans Language Meta-Package for LibreOffice</da>
   <de>Afrikaans Meta-Paket für LibreOffice</de>
   <el>LibreOffice στα Αφρικανικά</el>
   <en>Afrikaans Language Meta-Package for LibreOffice</en>
   <es_ES>Meta-Paquete de idioma africano para LibreOffice</es_ES>
   <es>Metapaquete de idioma Africano para LibreOffice</es>
   <et>Afrikaans Language Meta-Package for LibreOffice</et>
   <eu>Afrikaans Language Meta-Package for LibreOffice</eu>
   <fa>Afrikaans Language Meta-Package for LibreOffice</fa>
   <fil_PH>Afrikaans Language Meta-Package for LibreOffice</fil_PH>
   <fi>Afrikaansin kielipaketti LibreOffice:lle</fi>
   <fr_BE>Afrikaans Language Meta-Package for LibreOffice</fr_BE>
   <fr>Méta-Paquet de langue afrikanns pour LibreOffice</fr>
   <gl_ES>Africánder meta-paquete de idioma para LiberOffice</gl_ES>
   <gu>Afrikaans Language Meta-Package for LibreOffice</gu>
   <he_IL>חבילת על לשפת אפריקאנס עבור LibreOffice</he_IL>
   <hi>लिब्रे-ऑफिस हेतु अफ़्रीकी डच भाषा मेटा-पैकेज</hi>
   <hr>Afrikaans Language Meta-Package for LibreOffice</hr>
   <hu>Afrikaans Language Meta-Package for LibreOffice</hu>
   <id>Afrikaans Language Meta-Package for LibreOffice</id>
   <is>Afrikaans Language Meta-Package for LibreOffice</is>
   <it>Meta-pacchetto della lingua afrikaans per LibreOffice</it>
   <ja>LibreOffice 用のアフリカーンス語のメタパッケージ</ja>
   <kk>Afrikaans Language Meta-Package for LibreOffice</kk>
   <ko>Afrikaans Language Meta-Package for LibreOffice</ko>
   <lt>Afrikaans Language Meta-Package for LibreOffice</lt>
   <mk>Afrikaans Language Meta-Package for LibreOffice</mk>
   <mr>Afrikaans Language Meta-Package for LibreOffice</mr>
   <nb_NO>Afrikaans Language Meta-Package for LibreOffice</nb_NO>
   <nb>Afrikaans språkpakke for LibreOffice</nb>
   <nl_BE>Afrikaans Language Meta-Package for LibreOffice</nl_BE>
   <nl>Afrikaans Taal Meta-Pakket voor LibreOffice</nl>
   <pl>Meta-pakiet języka Afrikaans dla LibreOffice</pl>
   <pt_BR>Africâner Pacote de Idioma para o LibreOffice</pt_BR>
   <pt>Africander Meta-Pacote de Idioma para LibreOffice</pt>
   <ro>Afrikaans Language Meta-Package for LibreOffice</ro>
   <ru>Afrikaans Language Meta-Package for LibreOffice</ru>
   <sk>Afrikaans Language Meta-Package for LibreOffice</sk>
   <sl>Afrikaan jezikovni meta-paket za LibreOffice</sl>
   <sq>Afrikaans Language Meta-Package for LibreOffice</sq>
   <sr>Afrikaans Language Meta-Package for LibreOffice</sr>
   <sv>Afrikaans Språk Meta-Paket för LibreOffice</sv>
   <th>Meta-Package ภาษา Afrikaans สำหรับ LibreOffice</th>
   <tr>LibreOffice için Afrikaan Dili Üst-Paketi</tr>
   <uk>Afrikaans Language Meta-Package for LibreOffice</uk>
   <vi>Afrikaans Language Meta-Package for LibreOffice</vi>
   <zh_CN>LibreOffice 南非语语言包</zh_CN>
   <zh_HK>Afrikaans Language Meta-Package for LibreOffice</zh_HK>
   <zh_TW>Afrikaans Language Meta-Package for LibreOffice</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-l10n-af
libreoffice-gtk3
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-l10n-af
libreoffice-gtk3
</uninstall_package_names>

</app>
